# csvtodatabase

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 


## Description

It takes a CSV file as input and converts and save the data into a database.After a successful upload user can perform CRUD operations on the data using a localhost server. 

## Installation

- Run Following command to install.
 ```
  pip install csvtodatabase
  ```
